@@ -1,4 +1,4 @@
-//$Id: examplewindow.cc,v 1.3 2004/11/30 21:41:44 murrayc Exp $ -*- c++ -*-
+//$Id: examplewindow.cc,v 1.3.2.1 2005/04/15 19:02:51 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -129,7 +129,16 @@ void ExampleWindow::add_stock_item(const Glib::RefPtr<Gtk::IconFactory>& factory
                       const Glib::ustring& id, const Glib::ustring& label)
 {
   Gtk::IconSource source;
-  source.set_pixbuf( Gdk::Pixbuf::create_from_file(filepath) );
+  try
+  {
+    //This throws an exception if the file is not found:
+    source.set_pixbuf( Gdk::Pixbuf::create_from_file(filepath) );
+  }
+  catch(const Glib::Exception& ex)
+  {
+    std::cout << ex.what() << std::endl;
+  }
+
   source.set_size(Gtk::ICON_SIZE_SMALL_TOOLBAR);
   source.set_size_wildcarded(); //Icon may be scaled.
 
